@@ -38,9 +38,9 @@ def template(tmpdir):
 def ght(tmpdir, template: Repo):
     ght = GHT.init(
         path=os.path.join(tmpdir, "ght"),
-        template_url=f"file://{template.working_tree_dir}@master",
         config=dict(
             ght=dict(
+                template=dict(url=f"file://{template.working_tree_dir}", ref="master"),
                 hello="Hello World!",
                 a="alpha",
                 b="beta",
@@ -91,7 +91,6 @@ def test_ght_create_jinja2_environment(ght: GHT):
 
 def test_prepare_tree_for_rendering(ght: GHT):
     ght.prepare_tree_for_rendering()
-    assert ght.repo.active_branch == ght.repo.heads["ght/master"]
     assert "ght/template" not in ght.repo.heads
 
 
